@@ -19,14 +19,12 @@
 __author__ = 'api.sgrinberg@gmail.com (Stan Grinberg)'
 
 import os
-import re
 import thread
 import time
 
 from adspygoogle.adwords import AdWordsSanityCheck
 from adspygoogle.adwords import AUTH_TOKEN_SERVICE
 from adspygoogle.adwords import DEFAULT_API_VERSION
-from adspygoogle.adwords import LIB_SHORT_NAME
 from adspygoogle.adwords import LIB_SIG
 from adspygoogle.adwords import REQUIRED_SOAP_HEADERS
 from adspygoogle.adwords.GenericAdWordsService import GenericAdWordsService
@@ -191,16 +189,6 @@ class AdWordsClient(Client):
       # We need either oauth2credentials OR authToken.
       raise ValidationError('Authentication data is missing.')
 
-    # Insert library's signature into user agent.
-    if self._headers['userAgent'].rfind(LIB_SIG) == -1:
-      # Make sure library name shows up only once.
-      if self._headers['userAgent'].rfind(LIB_SHORT_NAME) > -1:
-        pattern = re.compile('.*' + LIB_SHORT_NAME + '.*?\|')
-        self._headers['userAgent'] = pattern.sub(
-            '', self._headers['userAgent'], 1)
-      self._headers['userAgent'] = (
-          '%s%s' % (self._headers['userAgent'], LIB_SIG))
-
     self.__is_mcc = False
 
     # Initialize logger.
@@ -933,6 +921,7 @@ class AdWordsClient(Client):
       version = DEFAULT_API_VERSION
     if Utils.BoolTypeConvert(self._config['strict']):
       AdWordsSanityCheck.ValidateServer(server, version)
+    AdWordsSanityCheck.ValidateService('CampaignSharedSetService', version)
 
     # Load additional configuration data.
     op_config = {
@@ -1444,6 +1433,7 @@ class AdWordsClient(Client):
       version = DEFAULT_API_VERSION
     if Utils.BoolTypeConvert(self._config['strict']):
       AdWordsSanityCheck.ValidateServer(server, version)
+    AdWordsSanityCheck.ValidateService('SharedCriterionService', version)
 
     # Load additional configuration data.
     op_config = {
@@ -1476,6 +1466,7 @@ class AdWordsClient(Client):
       version = DEFAULT_API_VERSION
     if Utils.BoolTypeConvert(self._config['strict']):
       AdWordsSanityCheck.ValidateServer(server, version)
+    AdWordsSanityCheck.ValidateService('SharedSetService', version)
 
     # Load additional configuration data.
     op_config = {
