@@ -31,10 +31,10 @@ from adspygoogle.common.Errors import MissingPackageError
 LIB_HOME = os.path.abspath(os.path.join(os.path.dirname(__file__)))
 LIB_NAME = 'AdWords API Python Client Library'
 LIB_SHORT_NAME = 'AwApi-Python'
-LIB_URL = 'http://code.google.com/p/google-api-ads-python'
+LIB_URL = 'https://github.com/googleads/googleads-python-lib'
 LIB_AUTHOR = 'Stan Grinberg'
 LIB_AUTHOR_EMAIL = 'api.sgrinberg@gmail.com'
-LIB_VERSION = '15.12.0'
+LIB_VERSION = '15.13.0'
 LIB_MIN_COMMON_VERSION = '3.1.1'
 LIB_SIG = GenerateLibSig(LIB_SHORT_NAME, LIB_VERSION)
 
@@ -44,7 +44,7 @@ if VERSION < LIB_MIN_COMMON_VERSION:
   raise MissingPackageError(msg)
 
 # Tuple of strings representing API versions.
-API_VERSIONS = ('v201306', 'v201309')
+API_VERSIONS = ('v201306', 'v201309', 'v201402')
 DEFAULT_API_VERSION = API_VERSIONS[-1]
 
 # Accepted combinations of headers which user has to provide. Either one of
