@@ -33,9 +33,9 @@ from adspygoogle.common.Errors import MissingPackageError
 LIB_HOME = os.path.abspath(os.path.join(os.path.dirname(__file__)))
 LIB_NAME = 'DFP API Python Client Library'
 LIB_SHORT_NAME = 'DfpApi-Python'
-LIB_URL = 'http://code.google.com/p/google-api-ads-python'
+LIB_URL = 'https://github.com/googleads/googleads-python-lib/'
 LIB_AUTHOR = 'Nicholas Chen'
-LIB_VERSION = '9.10.0'
+LIB_VERSION = '9.11.0'
 LIB_MIN_COMMON_VERSION = '3.1.1'
 LIB_SIG = GenerateLibSig(LIB_SHORT_NAME, LIB_VERSION)
 
@@ -45,7 +45,8 @@ if VERSION < LIB_MIN_COMMON_VERSION:
   raise MissingPackageError(msg)
 
 # Tuple of strings representing API versions.
-API_VERSIONS = ('v201208', 'v201211', 'v201302', 'v201306', 'v201308')
+API_VERSIONS = ('v201208', 'v201211', 'v201302', 'v201306', 'v201308',
+                'v201403')
 DEFAULT_API_VERSION = API_VERSIONS[-1]
 
 # Accepted combinations of headers which user has to provide. Either one of
@@ -58,6 +59,6 @@ AUTH_TOKEN_SERVICE = 'gam'
 AUTH_TOKEN_EXPIRE = 60 * 60 * 23
 
 ERROR_TYPES = []
-for item in Utils.GetDataFromCsvFile(os.path.join(LIB_HOME, 'data',
-                                                  'error_types.csv')):
+for item in Utils.GetDataFromCsvFile(
+    os.path.join(LIB_HOME, 'data', 'error_types.csv')):
   ERROR_TYPES.append(item[0])
